## rivendell.spec.in
##
##    The Rivendell Radio Automation System
##    Copyright (C) 2002-2022 Fred Gleason <fredg@paravelsystems.com>
##
##    This program is free software; you can redistribute it and/or modify
##    it under the terms of version 2 of the GNU General Public License as
##    published by the Free Software Foundation;
##
##    This program is distributed in the hope that it will be useful,
##    but WITHOUT ANY WARRANTY; without even the implied warranty of
##    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##    GNU General Public License for more details.
##
##    You should have received a copy of the GNU General Public License
##    along with this program; if not, write to the Free Software
##    Foundation, Inc., 59 Temple Place, Suite 330, 
##    Boston, MA  02111-1307  USA
##

# So python bytecompilation works correctly
%define __python /usr/bin/python3.6

Summary: Radio Broadcast Automation System
Name: rivendell
Version: 3.6.8
Release: 1
License: GPL
Packager: Fred Gleason <fredg@paravelsystems.com>
Source: rivendell-3.6.8.tar.gz
Requires: mariadb, qt-mysql, httpd, curl, usermode usermode-gtk, rivendell-pypad = 3.6.8, rsyslog libxslt
BuildRoot: /var/tmp/rivendell-3.6.8
Obsoletes: rivendell-base rivendell-opsguide
Conflicts: rivendell-opsguide

%package importers
Summary: Library importers for the Rivendell Broadcast Automation System
Requires: rivendell = 3.6.8, madplay

%package opsguide
Summary: Rivendell Operations and Administration Guide
BuildArch: noarch
Conflicts: rivendell

%package webapi
Summary: Client libraries for interfacing with Rivendell's Web API.

%package devel
Summary: Header files and example code for development with Rivendell APIs
Requires: rivendell = 3.6.8, rivendell-webapi = 3.6.8

%package pypad
Summary: PyPAD Program Associated Data script system for Rivendell
Requires: python36, python36-pycurl, python36-requests, python36-pyserial, python36-mysql python36-urllib3

%package select
Summary: The RDSelect system selector tool for Rivendell.
Requires: rivendell = 3.6.8, autofs

%package webget
Summary: The WebGet audio fetcher service for Rivendell
Requires: rivendell = 3.6.8


%description
Rivendell is a complete radio broadcast automation solution, with
facilities for the acquisition, management, scheduling and playout of
audio content.  Modules for the production and management of podcast
audio are also included.


%description importers
This package contains various importer scripts, which can be used to
import audio from existing legacy automation systems into Rivendell.
Currently, scripts exist for the AirForce Wings, Prophet NexGen and Sierra
Automated Systems SASAuto systems, as well as from another Rivendell system
(useful for 'merging' multiple databases).  Additionally, scripts for
initializing switcher matrices for the Christian Radio Consortium
(CRC) Unity4000 network and copying RDCatch event lists between hosts
are included.


%description opsguide
This package contains the Rivendell Operations and Administration Guide,
in both HTML and PDF formats.


%description webapi
This package contains client libraries for interfacing with Rivendell's
Web API subsystem.


%description devel
This package contains header files and example code for development using
Rivendell's Web C API, which can be used to integrate with Rivendell Web
API Interface.


%description pypad
This package contains Rivendell's PyPAD scripting system for transmitting
Program Associated Data (PAD) using of Python scripts.


%description select
This package contains the RDMonitor/RDSelect tool for Rivendell, which can
be used to select which amoung multiple Rivendell instances a host should be
associated with.


%description webget
This package contains the WebGet audio fetching tool for Rivendell.


%prep


%setup


%build
export PYTHON=/usr/bin/python3.6
%configure --libexecdir=/var/www/rd-bin --sysconfdir=/etc/httpd/conf.d 
make -j 11


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
rm -f $RPM_BUILD_ROOT//usr/lib64/libqmysqlutf*
mkdir $RPM_BUILD_ROOT/.qt
touch $RPM_BUILD_ROOT/.qt/qt
rm -rf $RPM_BUILD_ROOT//var/www/rd-bin/logos
mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d
cp conf/logrotate-sample $RPM_BUILD_ROOT/etc/logrotate.d/rivendell
mkdir -p $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/logos
cp icons/webget_logo.png $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/logos/
cp AUTHORS $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/
cp ChangeLog $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/
cp COPYING $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/
cp INSTALL $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/
cp NEWS $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/
cp README $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/
cp UPGRADING $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/
cp CODINGSTYLE $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/
cp conf/*.conf $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/
cat conf/rd.conf-sample | sed s/SyslogFacility=1/SyslogFacility=23/ > $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/rd.conf-sample
cp conf/asound.conf-sample $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/
mkdir -p $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/misc
cp conf/syslog.conf-sample $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/
mkdir -p $RPM_BUILD_ROOT/etc/fail2ban/filter.d
cp conf/rivendell-webapi.conf $RPM_BUILD_ROOT/etc/fail2ban/filter.d/
cp docs/misc/colors $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/misc/
cp docs/misc/reports.txt $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/misc/
cp docs/misc/ALSA.txt $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/misc/
cp docs/misc/RDMONITOR.txt $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/misc/
cp docs/misc/scheduler_formats.ods $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/misc/
cp docs/misc/ando_interface.odt $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/misc/
mkdir -p $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8
mkdir -p $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/apis
cp docs/apis/*.pdf $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/apis/
mkdir -p $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/dtds
cp docs/dtds/*.html $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/dtds/
cp docs/dtds/*.pdf $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/dtds/
mkdir -p $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/tables
cp docs/tables/*.txt $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/tables/
mkdir -p $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/scripts
cp scripts/rd_backup $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/scripts/
cp scripts/start_traverso.sh $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/scripts/
cp scripts/rd_mysql_enable_host.sh $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/scripts/
cp scripts/rd_backup_system.sh $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/scripts/
cp scripts/rd_restore_system.sh $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8/scripts/
cp scripts/engine_conv.py $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8
cp scripts/init_template_host.py $RPM_BUILD_ROOT//usr/share/doc/rivendell-3.6.8
rm -f $RPM_BUILD_ROOT/etc/auto.rd.audiostore
rm -rf $RPM_BUILD_ROOT%{_libdir}/rivendell/pypad/__pycache__
rm -rf $RPM_BUILD_ROOT%{_libdir}/python3.6/site-packages/__pycache__

%post
/sbin/ldconfig
/bin/systemctl daemon-reload
/usr/sbin/groupadd -r -g 150 %{name} &>/dev/null || :
/usr/sbin/useradd -o -u 150 -g %{name} -s /bin/false -r -c "Rivendell radio automation system" -d /var/snd %{name} &>/dev/null || :
if test ! -e /var/snd ; then
  mkdir -p /var/snd
  chown rivendell:rivendell /var/snd
  chmod 775 /var/snd
fi
if test ! -d /etc/rivendell.d ; then
  mkdir -p /etc/rivendell.d
  chmod 775 /etc/rivendell.d
fi
if test ! -e /etc/rd.conf ; then
  cp /usr/share/doc/rivendell-3.6.8/rd.conf-sample /etc/rivendell.d/rd-default.conf
  ln -s /etc/rivendell.d/rd-default.conf /etc/rd.conf
fi
if test ! -h /etc/rd.conf ; then
  mv /etc/rd.conf /etc/rivendell.d/rd-default.conf
  ln -s /etc/rivendell.d/rd-default.conf /etc/rd.conf
fi
if test ! -e /etc/asound.conf ; then
  cp /usr/share/doc/rivendell-3.6.8/asound.conf-sample /etc/asound.conf
fi
/usr/sbin/rddbmgr --modify
/bin/systemctl restart rivendell
/bin/systemctl enable rivendell
if test "redhat" = "suse" ; then
  /etc/init.d/apache2 restart
  insserv -d -f /etc/init.d/apache2 /etc/init.d/rivendell $MYSQL_INIT
fi
if test "redhat" = "redhat" ; then
  /bin/systemctl restart httpd
  /bin/systemctl enable httpd
fi
if [ -x %{_bindir}/gtk-update-icon-cache ] ; then
  %{_bindir}/gtk-update-icon-cache -f --quiet %{_datadir}/icons/hicolor || :
fi
if test ! -e /var/www/rd-bin/logos ; then
    mkdir -p /var/www/rd-bin/logos
fi
if test ! -f /var/www/rd-bin/logos/webget_logo.png ; then
    cp /usr/share/doc/rivendell-3.6.8/logos/webget_logo.png /var/www/rd-bin/logos/webget_logo.png
fi
mkdir -p /var/log/rivendell
if test ! -e /etc/rsyslog.d/rivendell.conf ; then
    cp /usr/share/doc/rivendell-3.6.8/syslog.conf-sample /etc/rsyslog.d/rivendell.conf
fi
/bin/systemctl restart rsyslog
exit 0


%preun
if test "$1" = "0" ; then
  /bin/systemctl stop rivendell
  if test "redhat" = "suse" ; then
    insserv -r -d -f /etc/init.d/rivendell
  fi
  if test "redhat" = "redhat" ; then
    /bin/systemctl disable rivendell
    /bin/systemctl stop rivendell
  fi
fi
exit 0


%postun
if [ -x %{_bindir}/gtk-update-icon-cache ] ; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi
/bin/systemctl daemon-reload


%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
/usr/bin/rdadmin
/usr/bin/rdairplay
/usr/bin/rdpanel
/usr/bin/rdcartslots
/usr/bin/rdcatch
/usr/bin/rdgen
/usr/bin/rdlibrary
/usr/bin/rdlogedit
/usr/bin/rdlogmanager
/usr/bin/rdcastmanager
/usr/bin/rdlogin
/usr/bin/rmlsend
/usr/bin/rdsoftkeys
/usr/bin/rdpopup
/usr/bin/rdalsaconfig
/usr/bin/rdalsaconfig-root
/usr/bin/rdgpimon
/usr/bin/rdclilogedit
/usr/bin/rddbconfig
/usr/bin/rddbconfig-root
/usr/bin/rddelete
/usr/bin/rdexport
/usr/bin/rdimport
/usr/bin/rdmetadata
/usr/bin/rdmaint
/usr/bin/rdcollect
/usr/bin/rdconvert
/usr/bin/rdcheckcuts
/usr/bin/rd_audio_sync
/usr/bin/rd_config
/usr/bin/sage_endec_rwt.sh
/usr/bin/rd_backup
/usr/bin/rdmemcheck.sh
/usr/bin/rdrender
/usr/share/rivendell/*.qm
/usr/share/rivendell/*.xsl
/usr/share/icons/hicolor/16x16/apps/rivendell.png
/usr/share/icons/hicolor/16x16/apps/rdadmin.png
/usr/share/icons/hicolor/16x16/apps/rdairplay.png
/usr/share/icons/hicolor/16x16/apps/rdcartslots.png
/usr/share/icons/hicolor/16x16/apps/rdcastmanager.png
/usr/share/icons/hicolor/16x16/apps/rdcatch.png
/usr/share/icons/hicolor/16x16/apps/rdlibrary.png
/usr/share/icons/hicolor/16x16/apps/rdlogedit.png
/usr/share/icons/hicolor/16x16/apps/rdlogmanager.png
/usr/share/icons/hicolor/16x16/apps/rdpanel.png
/usr/share/icons/hicolor/22x22/apps/rivendell.png
/usr/share/icons/hicolor/22x22/apps/rdadmin.png
/usr/share/icons/hicolor/22x22/apps/rdairplay.png
/usr/share/icons/hicolor/22x22/apps/rdcartslots.png
/usr/share/icons/hicolor/22x22/apps/rdcastmanager.png
/usr/share/icons/hicolor/22x22/apps/rdcatch.png
/usr/share/icons/hicolor/22x22/apps/rdlibrary.png
/usr/share/icons/hicolor/22x22/apps/rdlogedit.png
/usr/share/icons/hicolor/22x22/apps/rdlogmanager.png
/usr/share/icons/hicolor/22x22/apps/rdpanel.png
/usr/share/icons/hicolor/32x32/apps/rivendell.png
/usr/share/icons/hicolor/32x32/apps/rdadmin.png
/usr/share/icons/hicolor/32x32/apps/rdairplay.png
/usr/share/icons/hicolor/32x32/apps/rdcartslots.png
/usr/share/icons/hicolor/32x32/apps/rdcastmanager.png
/usr/share/icons/hicolor/32x32/apps/rdcatch.png
/usr/share/icons/hicolor/32x32/apps/rdlibrary.png
/usr/share/icons/hicolor/32x32/apps/rdlogedit.png
/usr/share/icons/hicolor/32x32/apps/rdlogmanager.png
/usr/share/icons/hicolor/32x32/apps/rdpanel.png
/usr/share/icons/hicolor/64x64/apps/rivendell.png
/usr/share/icons/hicolor/64x64/apps/rdadmin.png
/usr/share/icons/hicolor/64x64/apps/rdairplay.png
/usr/share/icons/hicolor/64x64/apps/rdcartslots.png
/usr/share/icons/hicolor/64x64/apps/rdcastmanager.png
/usr/share/icons/hicolor/64x64/apps/rdcatch.png
/usr/share/icons/hicolor/64x64/apps/rdlibrary.png
/usr/share/icons/hicolor/64x64/apps/rdlogedit.png
/usr/share/icons/hicolor/64x64/apps/rdlogmanager.png
/usr/share/icons/hicolor/64x64/apps/rdpanel.png
/usr/share/icons/hicolor/128x128/apps/rivendell.png
/usr/share/icons/hicolor/128x128/apps/rdadmin.png
/usr/share/icons/hicolor/128x128/apps/rdairplay.png
/usr/share/icons/hicolor/128x128/apps/rdcartslots.png
/usr/share/icons/hicolor/128x128/apps/rdcastmanager.png
/usr/share/icons/hicolor/128x128/apps/rdcatch.png
/usr/share/icons/hicolor/128x128/apps/rdlibrary.png
/usr/share/icons/hicolor/128x128/apps/rdlogedit.png
/usr/share/icons/hicolor/128x128/apps/rdlogmanager.png
/usr/share/icons/hicolor/128x128/apps/rdpanel.png
/usr/share/icons/hicolor/256x256/apps/rivendell.png
/usr/share/icons/hicolor/256x256/apps/rdadmin.png
/usr/share/icons/hicolor/256x256/apps/rdairplay.png
/usr/share/icons/hicolor/256x256/apps/rdcartslots.png
/usr/share/icons/hicolor/256x256/apps/rdcastmanager.png
/usr/share/icons/hicolor/256x256/apps/rdcatch.png
/usr/share/icons/hicolor/256x256/apps/rdlibrary.png
/usr/share/icons/hicolor/256x256/apps/rdlogedit.png
/usr/share/icons/hicolor/256x256/apps/rdlogmanager.png
/usr/share/icons/hicolor/256x256/apps/rdpanel.png
/usr/share/icons/hicolor/512x512/apps/rivendell.png
/usr/share/icons/hicolor/512x512/apps/rdadmin.png
/usr/share/icons/hicolor/512x512/apps/rdairplay.png
/usr/share/icons/hicolor/512x512/apps/rdcartslots.png
/usr/share/icons/hicolor/512x512/apps/rdcastmanager.png
/usr/share/icons/hicolor/512x512/apps/rdcatch.png
/usr/share/icons/hicolor/512x512/apps/rdlibrary.png
/usr/share/icons/hicolor/512x512/apps/rdlogedit.png
/usr/share/icons/hicolor/512x512/apps/rdlogmanager.png
/usr/share/icons/hicolor/512x512/apps/rdpanel.png
/usr/share/X11/fvwm2/pixmaps/mini.rivendell.xpm
/usr/share/X11/fvwm2/pixmaps/rivendell.xpm
/usr/share/applications/rivendell-rdadmin.desktop
/usr/share/applications/rivendell-rdlogin.desktop
/usr/share/applications/rivendell-rdairplay.desktop
/usr/share/applications/rivendell-rdmonitor.desktop
/usr/share/applications/rivendell-rdpanel.desktop
/usr/share/applications/rivendell-rdcartslots.desktop
/usr/share/applications/rivendell-rdcatch.desktop
/usr/share/applications/rivendell-rdgpimon.desktop
/usr/share/applications/rivendell-rdalsaconfig-root.desktop
/usr/share/applications/rivendell-rddbconfig-root.desktop
/usr/share/applications/rivendell-rdlibrary.desktop
/usr/share/applications/rivendell-rdlogedit.desktop
/usr/share/applications/rivendell-rdlogmanager.desktop
/usr/share/applications/rivendell-rdcastmanager.desktop
/usr/share/applications/rivendell-rmlsend.desktop
/usr/share/applications/rivendell-rdsoftkeys.desktop
/usr/share/desktop-directories/rivendell-configuration.directory
/usr/share/desktop-directories/rivendell-documentation.directory
/usr/share/desktop-directories/rivendell-logtools.directory
/usr/share/desktop-directories/rivendell-rivendell.directory
/usr/share/desktop-directories/rivendell-utilities.directory
/etc/xdg/menus/applications-merged/rivendell-rivendell.menu
/etc/logrotate.d/rivendell
/.qt/qt
/var/www/rd-bin/*.gif
/var/www/rd-bin/*.html
/var/www/rd-bin/editcart.js
/var/www/rd-bin/editcut.js
/var/www/rd-bin/utils.js
/var/www/rd-bin/*.png
%attr(6755,root,root) /var/www/rd-bin/rdxport.cgi
/etc/httpd/conf.d/rd-bin.conf
/etc/security/console.apps/rdalsaconfig-root
/etc/pam.d/rdalsaconfig-root
/etc/security/console.apps/rddbconfig-root
/etc/pam.d/rddbconfig-root
/etc/pam.d/rivendell
/etc/fail2ban/filter.d/rivendell-webapi.conf
/lib/systemd/system/rivendell.service
%{_mandir}/man1/rdairplay.1.gz
%{_mandir}/man1/rdalsaconfig.1.gz
%{_mandir}/man1/rdclilogedit.1.gz
%{_mandir}/man1/rdconvert.1.gz
%{_mandir}/man1/rdexport.1.gz
%{_mandir}/man1/rdimport.1.gz
%{_mandir}/man1/rdlogmanager.1.gz
%{_mandir}/man1/rdmetadata.1.gz
%{_mandir}/man1/rdrender.1.gz
%{_mandir}/man1/rmlsend.1.gz
%{_mandir}/man1/rdsoftkeys.1.gz
%{_mandir}/man5/rd.conf.5.gz
%{_mandir}/man8/rddbmgr.8.gz
%{_mandir}/man8/rdmarkerset.8.gz
%{_mandir}/man8/rdservice.8.gz
/usr/share/doc/rivendell-3.6.8/*
/usr/lib64/librd-3.6.8.so
/usr/lib64/librd.a
/usr/lib64/librd.la
/usr/lib64/librd.so
/usr/sbin/rdservice
/usr/sbin/caed
/usr/sbin/ripcd
/usr/sbin/rdcatchd
/usr/sbin/rdvairplayd
/usr/sbin/rdrepld
/usr/sbin/rdpadd
/usr/sbin/rdpadengined
/usr/sbin/rdrssd
/usr/sbin/rdmarkerset
/usr/sbin/rdcleandirs
/usr/sbin/rddbmgr
/usr/lib64/librdhpi-3.6.8.so
/usr/lib64/librdhpi.a
/usr/lib64/librdhpi.la
/usr/lib64/librdhpi.so
/etc/auto.master.d/rd.audiostore.autofs
/usr/share/rivendell/opsguide.pdf
/usr/share/rivendell/html
/usr/share/rivendell/manpages
/usr/share/rivendell/manpages/html
/usr/share/rivendell/apis
/usr/share/rivendell/apis/html


%files webapi
/usr/lib64/librivwebcapi.so.0
/usr/lib64/librivwebcapi.so.0.1.0


%files importers
/usr/bin/wings_filter
/usr/bin/rivendell_filter
/usr/bin/nexgen_filter
/usr/bin/sas_filter
/usr/bin/crc-unity4k.sh
/usr/bin/rdcatch_copy
/usr/bin/panel_copy
/usr/bin/rddgimport
/usr/bin/rddiscimport
/usr/share/applications/rivendell-rddgimport.desktop
/usr/share/applications/rivendell-rddiscimport.desktop


%files opsguide
/usr/share/rivendell/opsguide.pdf
/usr/share/rivendell/html/*
/usr/share/rivendell/apis
/usr/share/rivendell/manpages


%files devel
/usr/lib64/librivwebcapi.so
/usr/lib64/librivwebcapi.a
/usr/lib64/librivwebcapi.la
/usr/lib64/pkgconfig/rivwebcapi.pc
/usr/include/rivwebcapi/*
/usr/share/man/man7/rd_addcart.7.gz
/usr/share/man/man7/rd_addcut.7.gz
/usr/share/man/man7/rd_addlog.7.gz
/usr/share/man/man7/rd_assignschedcode.7.gz
/usr/share/man/man7/rd_audioinfo.7.gz
/usr/share/man/man7/rd_audiostore.7.gz
/usr/share/man/man7/rd_copyaudio.7.gz
/usr/share/man/man7/rd_createticket.7.gz
/usr/share/man/man7/rd_deleteaudio.7.gz
/usr/share/man/man7/rd_deletelog.7.gz
/usr/share/man/man7/rd_deletepodcast.7.gz
/usr/share/man/man7/rd_editcart.7.gz
/usr/share/man/man7/rd_editcut.7.gz
/usr/share/man/man7/rd_export.7.gz
/usr/share/man/man7/rd_exportpeaks.7.gz
/usr/share/man/man7/rd_getuseragent.7.gz
/usr/share/man/man7/rd_getversion.7.gz
/usr/share/man/man7/rd_import.7.gz
/usr/share/man/man7/rd_listcart.7.gz
/usr/share/man/man7/rd_listcartcuts.7.gz
/usr/share/man/man7/rd_listcarts.7.gz
/usr/share/man/man7/rd_listcartscuts.7.gz
/usr/share/man/man7/rd_listcartschedcodes.7.gz
/usr/share/man/man7/rd_listcut.7.gz
/usr/share/man/man7/rd_listcuts.7.gz
/usr/share/man/man7/rd_listgroup.7.gz
/usr/share/man/man7/rd_listgroups.7.gz
/usr/share/man/man7/rd_listlog.7.gz
/usr/share/man/man7/rd_listlogs.7.gz
/usr/share/man/man7/rd_listschedcodes.7.gz
/usr/share/man/man7/rd_listservices.7.gz
/usr/share/man/man7/rd_listsystemsettings.7.gz
/usr/share/man/man7/rd_postimage.7.gz
/usr/share/man/man7/rd_postpodcast.7.gz
/usr/share/man/man7/rd_postrss.7.gz
/usr/share/man/man7/rd_removecart.7.gz
/usr/share/man/man7/rd_removecut.7.gz
/usr/share/man/man7/rd_removeimage.7.gz
/usr/share/man/man7/rd_removepodcast.7.gz
/usr/share/man/man7/rd_removerss.7.gz
/usr/share/man/man7/rd_savelog.7.gz
/usr/share/man/man7/rd_savepodcast.7.gz
/usr/share/man/man7/rd_trimaudio.7.gz
/usr/share/man/man7/rd_unassignschedcode.7.gz


%files pypad
%{_libdir}/rivendell/pypad/*
%{_libdir}/python3.6/site-packages/pypad*
%{_libdir}/python3.6/site-packages/__pycache__/pypad*


%post pypad
/usr/sbin/groupadd -r -g 151 pypad &>/dev/null || :
/usr/sbin/useradd -o -u 151 -g pypad -s /bin/false -r -c "Rivendell PyPAD scripts" -d /dev/null pypad &>/dev/null || :


%files select
/usr/bin/rdselect
%attr(4755,root,root) /usr/bin/rdselect_helper
/usr/bin/rdmonitor
/etc/X11/xinit/xinitrc.d/start-rdmonitor.sh


%files webget
%attr(6755,root,root) /var/www/rd-bin/webget.cgi
/var/www/rd-bin/webget.js


%post select
touch /etc/auto.rd.audiostore
systemctl restart autofs


%postun select
systemctl restart autofs


%changelog
* Mon Nov 20 2023 Fred Gleason <fredg@paravelsystems.com> - 3.6.8-1
-- Autogenerated from build tree.
